PMPathFilter class

Constructors

PMPathFilter({PMDarwinPathFilter darwin = const PMDarwinPathFilter(), PMOhosPathFilter ohos = const PMOhosPathFilter()})
For filter the AssetPathEntity.
const

Properties

darwin → PMDarwinPathFilter
For macOS and iOS.
final
hashCode → int
The hash code for this object.
no setterinherited
ohos → PMOhosPathFilter
For OpenHarmony.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited